# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-autodie
Version:	2.37
Release:	1.%{__distinit}%{__distvers}
Summary:	Replace functions with ones that succeed or die
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/autodie
Source0:	https://cpan.metacpan.org/authors/id/T/TO/TODDR/autodie-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(IPC::System::Simple) >= 0.12
BuildRequires:	perl(overload)
BuildRequires:	perl(parent)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Tie::RefHash)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Fatal)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(if)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(lib)
BuildRequires:	perl(open)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Sub::Identify)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(BSD::Resource)
BuildRequires:	perl(Import::Into) >= 1.002004
# perl-Test-Perl-Critic → perl-Perl-Critic → perl-autodie
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Runtime
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Fcntl)
Requires:	perl(IPC::System::Simple) >= 0.12
Requires:	perl(POSIX)
Requires:	perl(Sub::Identify)

%description
The autodie pragma has lexical scope, meaning that functions and subroutines
altered with autodie will only change their behavior until the end of the
enclosing block, file, or eval.

If system is specified as an argument to autodie, then it uses
IPC::System::Simple to do the heavy lifting.

%prep
%setup -q -n autodie-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTHOR_TESTING=1 RELEASE_TESTING=1

%files
%license LICENSE
%doc AUTHORS Changes README.md
%{perl_vendorlib}/Fatal.pm
%{perl_vendorlib}/autodie.pm
%{perl_vendorlib}/autodie/
%{_mandir}/man3/autodie.3*
%{_mandir}/man3/autodie::exception.3*
%{_mandir}/man3/autodie::exception::system.3*
%{_mandir}/man3/autodie::hints.3*
%{_mandir}/man3/autodie::Scope::Guard.3*
%{_mandir}/man3/autodie::Scope::GuardStack.3*
%{_mandir}/man3/autodie::skip.3*
%{_mandir}/man3/autodie::Util.3*
%{_mandir}/man3/Fatal.3*

%changelog
* Fri Dec 29 2023 Paul Howarth <paul@city-fan.org> - 2.37-1
- Update to 2.37
  - Deprecate smartmatch handling (GH#117)
  - Remove mention of cpanratings.perl.org (GH#118)
  - Fix typo in changelog (GH#119)

* Tue Jan 31 2023 Paul Howarth <paul@city-fan.org> - 2.36-1
- Update to 2.36
  - Remove the use of ' as a package separator
  - Fix spelling errors in POD

* Sat Jan 28 2023 Paul Howarth <paul@city-fan.org> - 2.35-1
- Update to 2.35
  - Prepare for 5.38 changes to deprecate smartmatch
  - Remove +x bit from pm and t files
  - CI - Turn off Pod coverage and critic tests below 5.12
- Use SPDX-format license tag

* Sat Jan 23 2021 Paul Howarth <paul@city-fan.org> - 2.34-1
- Update to 2.34
  - Remove rt.cpan.org reference

* Fri Jan 22 2021 Paul Howarth <paul@city-fan.org> - 2.33-1
- Update to 2.33
  - Switch to testsuite CI workflow
  - Add 2.33 support to Fatal.pm
  - Add missing use Scalar::Utils for using bless
  - Fix typo
  - Update bug tracker to GitHub to prepare for RT shutdown
- Use %%license unconditionally

* Fri Jan 17 2020 Paul Howarth <paul@city-fan.org> - 2.32-1
- Update to 2.32
  - Update automated tests to include soft dependencies
  - Remove Test::Perl::Critic as a testing requirement
  - Update README.md to show github actions' status, not Travis

* Wed Jan  8 2020 Paul Howarth <paul@city-fan.org> - 2.31-1
- Update to 2.31
  - Correct diag explain in t/version.t so it'll pass on perl 5.8
  - Only test t/no-all.t if optional IPC::System::Simple is available
  - Switch automated testing to github actions
  - Turn off t/kill.t for Windows; recent versions of Windows seem to choke
    when doing: `kill 0, $$;`

* Fri Jan  3 2020 Paul Howarth <paul@city-fan.org> - 2.30-1
- Update to 2.30
  - Fix a boolean logic precedence error causing a "useless use of numeric"
    warning when using kill with a signal of 0 (GH#76)
  - Fix a scoping issue with "no autodie" and the "system" sub (GH#69)
  - Update code and documentation about smartmatch to match current the current
    support in perl (GH#83)
  - Fix a POD error and some unnecessary spaces that tripped POD parsers (GH#51
    and GH#79)
  - Document how to use Import::Into with autodie (GH#50)
  - Clean up of dzil.ini removing some unnecessary test recommends (GH#78)
  - Set binmode on some file handles to fix issues on Windows (GH#83)
  - Travis: Also test with Perl 5.22, 5.24, 5.26 and 5.28
- This release by TODDR → update source URL
- Always ship manpage for Fatal.pm
- Some Author/Release tests moved to xt/, drop buildreqs for them

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 2.29-439
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop legacy BuildRoot: and Group: tags

* Thu Aug  4 2016 Paul Howarth <paul@city-fan.org> - 2.29-366
- BR: perl-generators where available
- Simplify find command using -delete
- Fix FTBFS where perl is not in the minimal buildroot

* Thu Jul  9 2015 Paul Howarth <paul@city-fan.org> - 2.29-1
- Update to 2.29
  - Install autodie and Fatal into 'perl' rather than 'site' for older perls
    (CPAN RT#85801, GH#68)

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 2.28-1
- Update to 2.28
  - Deprecate the use of "Fatal qw(:lexical)"; it is an implementation detail
    of autodie and is about to change
  - Use octal numbers in error messages for CORE subroutines taking a "mode"
    parameter, e.g. mkdir and chmod (GH#65, GH#66)
  - Allow wrappers for CORE::exec and CORE::system to be reused as they are not
    dependent on the calling package
  - Avoid hard-coded directory separator in t/system.t (GH#62)
  - Add missing "require autodie" in import-into test and ensure Import::Into
    remains an optional test dependency
  - Travis: set "sudo: false" to gain access to the Travis container based
    infrastructure
  - Bump version of Import::Into to 1.002004 as older versions are insufficient
    for our test (CPAN RT#101377)
  - Properly skip the Import::Into test if the version of Import::Into is
    insufficient (GH#67)
- This release by PJF → update source URL

* Mon Jan  5 2015 Paul Howarth <paul@city-fan.org> - 2.26-1
- Update to 2.26
  - Remove "fileno" and "umask" from the list of CORE subs protected by
    autodie and Fatal; when they return undef, it is not a failure
  - Fixed an error that could occur during global destruction of the form
    "(in cleanup) Can't use an undefined value as an ARRAY reference at
    .../autodie/Scope/GuardStack.pm line 48 during global destruction"
  - The open-pragma is now properly ignored when open is given an explicit
    layer; this brings autodie protected open in sync with open (GH#52, GH#53)
  - Hide the "SCALAR" (buffer) argument in the string representation of
    autodie::exception for the read, sysread and syswrite CORE subs; this is
    to avoid a dump of binary data to the screen/log when a (sys)read or
    syswrite fails
  - Let autodie::exception work in equality tests and string comparison via
    "overload fallback"
  - Documentation: mention that "kill" is in the ":ipc" category; it has been
    there since autodie v2.14 (CPAN RT#97320)
  - Use "parent" instead of "base" for inheritance; also avoid some @ISA
    relationships that were redundant (either truly redundant ones or by
    importing "import" from Exporter v5.57) (GH#59)
  - The autodie module now accepts an undefined Fatal version, assuming it to
    be development version; test cases that require versions are now either
    skipped or considered "release" test
  - Enabled travis-ci for Perl 5.20
  - Close temp file before re-opening in t/truncate.t (CPAN RT#96609)
  - Pass O_TRUNC with O_CREAT to sysopen in t/utf8_open.t (CPAN RT#87237)
  - Clean up temp file in t/truncate.t (CPAN RT#100688)
- This release by NTHYKIER → update source URL
- Classify buildreqs by usage

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 2.25-4
- Use %%license where possible

* Thu Apr  3 2014 Paul Howarth <paul@city-fan.org> - 2.25-1
- Update to 2.25
  - DOCS: Spelling fixes in autodie::ScopeUtil

* Sun Mar 30 2014 Paul Howarth <paul@city-fan.org> - 2.24-1
- Update to 2.24
  - FEATURE: Provide a stack backtrace when `Carp::Always` is enabled (GH #35)
  - BUGFIX: Fix situations where `no autodie` doesn't respect lexical scope
    (GH #41, CPAN RT#72053, CPAN RT#86396)
  - INTERNAL: Remove now-unused variables in code
  - DOCS: Make it extra-clear autodie doesn't check `print` (GH #39)
  - TEST: Removed obsolete boilerplate.t
  - TEST/INTERNAL: Enabled travis-ci for Perl 5.8
  - TEST: Stopped some Pod::Coverage tests failing under Perl 5.8
  - BUILD: Better support for building in a read-only directory (GH #46)
- Drop support for old distributions prior to FC-5:
  - Drop patch for building with ExtUtils::MakeMaker < 6.30
  - Drop %%defattr, redundant since rpm 4.4
- Enable Pod Coverage test now that it passes
- README is now README.md
- Package new manpages for autodie::Scope::Guard, autodie::Scope::GuardStack
  and autodie::ScopeUtil

* Mon Jan 27 2014 Paul Howarth <paul@city-fan.org> - 2.23-1
- Update to 2.23
  - TEST/BUGFIX: Improved testing support on Android and Blackberry devices
    (GH #44)
  - TEST/INTERNAL/TRAVIS: Various non-code tweaks to make travis-ci more happy
    with testing autodie
  - BUGFIX: autodie no longer weakens strict by allowing undeclared variables
    with the same name as built-ins (CPAN RT#74246)
  - BUGFIX: `use autodie qw( foo ! foo);` now correctly insists that we have
    hints for foo
  - INTERNAL: Improved benchmarking code
- Update patch to support building with ExtUtils::MakeMaker < 6.30

* Sat Sep 21 2013 Paul Howarth <paul@city-fan.org> - 2.22-1
- Update to 2.22
  - TEST/INTERNAL: Restore timestamps on touched testing files to avoid git
    flagging files having changed in git (CPAN RT#88444)

* Thu Sep 12 2013 Paul Howarth <paul@city-fan.org> - 2.21-1
- Update to 2.21
  - SPEED/INTERNAL: Through the magic of globally reuseable core leak
    trampolines, autodie is even faster when used across multiple packages
  - SPEED/INTERNAL: Caches used for keeping track of fatalised subroutines are
    faster and leaner
  - SPEED/INTERNAL: Core subroutine wrappers are now lazily compiled
  - SPEED/INTERNAL: Using autodie while autodie is already in effect is now
    faster and more efficient
  - INTERNAL: $" and $! are no longer arbitrarily messed with for no reason via
    autodie (they're still messed with when using Fatal)
  - SPEED/INTERNAL: The ':all' tag hierachy is expanded immediately, in an
    efficient fashion
  - INTERNAL: Numerous minor clean-ups, dead variables removed, typos fixed
  - SPEED/INTERNAL: import() and _make_fatal() cache more aggressively,
    reducing CPU overhead
  - TEST: Compatibility with Carp 1.32 (CPAN RT#88076)
- Don't run the Kwalitee test on 5.8.x

* Sun Sep  1 2013 Paul Howarth <paul@city-fan.org> - 2.20-4
- Don't ship the manpage for Fatal.pm for 5.8 as it'll conflict with the legacy
  one in the main perl package

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 2.20-3
- Perl 5.18 rebuild

* Fri Jul  5 2013 Paul Howarth <paul@city-fan.org> - 2.20-2
- BR: perl(ExtUtils::MakeMaker)
- Don't run Critic or Kwalitee tests when bootstrapping

* Mon Jun 24 2013 Paul Howarth <paul@city-fan.org> - 2.20-1
- Update to 2.20
  - SPEED/INTERNAL: Less time is spent computing prototypes
  - SPEED/INTERNAL: Leak guards are more efficient
  - SPEED: Expanding tags (eg: qw(:all)) is now faster; this also improves the
    speed of checking autodying code with Perl::Critic
  - INTERNAL: Expanding of tags is faster and preserves order

* Mon May 13 2013 Paul Howarth <paul@city-fan.org> - 2.19-1
- Update to 2.19
  - BUGFIX: Loading a file that does not change packages while autodie in
    effect no longer causes weird behaviour when slurpy built-ins (like open()
    and unlink()) are called (GH #22)
  - TEST: More testing in scope_leak.t
  - TEST: More testing around packages in truncate.t
  - TEST: Tests for leak guard failures for slurpy core functions
  - SPEED/INTERNAL: Significant improvements in load time, especially when
    autodie is used across multiple files, by caching reuseable subroutines
    and reducing calls to eval "" (CPAN RT#46984)
  - DOCUMENTATION: Spelling and correction fixes
  - DEVEL: Faster and more robust testing with travis-ci
  - DEVEL: Some simple benchmarks bundled in the benchmarks/ directory

* Sun Apr 28 2013 Paul Howarth <paul@city-fan.org> - 2.17-1
- Update to 2.17
  - Spelling fixes thanks to dsteinbrunner! (CPAN RT#84897)
  - Fixed github links to point to 'pjf' rather than 'pfenwick' (GH #18)
  - Silence warnings about experimental smart-match on 5.17.11+
  - Generate .travis.yml files for CI testing via dzil

* Fri Feb 22 2013 Paul Howarth <paul@city-fan.org> - 2.16-1
- Update to 2.16
  - Classes that claim they ->DOES('autodie::skip') are now skipped when
    generating exceptions; this is mainly of use to utility classes - see
    'perldoc autodie::skip' for more details (GH Issue #15)
  - 'chmod' is now in the ':filesys' category (was in ':file')
  - Added support for 'chown' and 'utime', which was previously overlooked;
    these are all in the ':filesys' category (GH Pull #13)
  - Added support for 'kill' (this is part of the ':ipc' category)
  - Fixed bug whereby chmod, chown, kill, unlink and utime would not throw an
    exception when they didn't change all their files or signal all their
    processes
  - truncate.t is now skipped on systems that don't have a working File::Temp
  - open.t has a few more tests for exotic modes
  - chown() tests are skipped on Win32, as chown on Windows is a no-op
  - Author tests now look for the AUTHOR_TESTING env variable (for dzil
    compliance)
  - Better testing for chown, chmod, ulink and unlink
  - kwalitee.t is now only run when $ENV{RELEASE_TESTING} is set
  - Removed executable bits from some bundled text files
  - We now use dzil to manage autodie
  - Only Perl 5.8.4 and above is supported by autodie
- New manpage for autodie::skip
- Upstream dropped TODO, added LICENSE
- No longer need to fix permissions in %%prep
- Drop BR: perl(Cwd), no longer needed as Module::Install dropped
- BR: perl ≥ 3:5.8.4 as per upstream
- BR: perl(Exporter), perl(File::Copy), perl(File::Spec), perl(File::Temp),
  perl(IO::Handle), perl(parent) and perl(Socket)
- Specify version requirements for Test::Pod and Test::Pod::Coverage
- Add BuildConflict for perl(Pod::Coverage::TrustPod) because there's a naked
  subroutine found in the release pod coverage test
- Add patch to support building with ExtUtils::MakeMaker < 6.30

* Thu Nov  8 2012 Paul Howarth <paul@city-fan.org> - 2.13-1
- Update to 2.13
  - Deterministic tests in hints_pod_examples.t (CPAN RT#80412)
  - Subroutine installs are now done in a deterministic order (CPAN RT#80414)

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 2.12-1
- Update to 2.12
  - autodie now plays nicely with the 'open' pragma (CPAN RT#54777)
  - Updated to Module::Install 1.06
  - Makefile.PL is less redundant
  - t/pod-coverage.t no longer thinks LEXICAL_TAG is a user-visible subroutine

* Fri Mar 23 2012 Paul Howarth <paul@city-fan.org> - 2.11-1
- Update to 2.11
  - Explicitly documented that autodie is context-unaware
  - Multi-arg open tests are skipped on VMS
  - Bugfix: recv.t shouldn't assume STDIN is a file handle
  - Fixed compatibility with Carp 1.25
  - Exception classes are loaded more safely
- Add buildreqs for Perl core modules that could be dual-lived
- BR: perl(Test::Pod::Coverage) now that coverage test passes
- Don't need to remove empty directories from buildroot
- Drop compatibility with distributions prior to FC-3:
  - Drop patch for CPAN RT#53506
  - Don't need to define %%{perl_vendorlib}
  - BR: perl(Test::Perl::Critic) unconditionally
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> - 2.10-4
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 2.10-3
- Unconditionally BR: perl(Test::Kwalitee)
- Nobody else likes macros for commands

* Tue Mar 22 2011 Paul Howarth <paul@city-fan.org> - 2.10-2
- BR: perl(Test::Kwalitee)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 2.10-1
- Initial RPM version
